summaryrefslogtreecommitdiff
path: root/include/linux/gpio/driver.h
diff options
context:
space:
mode:
authorMark Brown <broonie@linaro.org>2013-12-31 16:59:55 +0400
committerMark Brown <broonie@linaro.org>2013-12-31 16:59:55 +0400
commit68066bb378a0504439e046cdb55d88362eb6379d (patch)
tree0b60f72ddf7108a63dd4db617b42e07fbae5346d /include/linux/gpio/driver.h
parent43f627ac9de42607b2cdcc7a41f2bcc82187e06a (diff)
parent802eee95bde72fd0cd0f3a5b2098375a487d1eda (diff)
downloadlinux-68066bb378a0504439e046cdb55d88362eb6379d.tar.xz
Merge tag 'v3.13-rc6' into spi-dw
To resolve trivial overlaps with fixes. Linux 3.13-rc6
Diffstat (limited to 'include/linux/gpio/driver.h')
-rw-r--r--include/linux/gpio/driver.h14
1 files changed, 12 insertions, 2 deletions
diff --git a/include/linux/gpio/driver.h b/include/linux/gpio/driver.h
index 656a27efb2c8..3ea2cf6b0e6c 100644
--- a/include/linux/gpio/driver.h
+++ b/include/linux/gpio/driver.h
@@ -2,9 +2,12 @@
#define __LINUX_GPIO_DRIVER_H
#include <linux/types.h>
+#include <linux/module.h>
struct device;
struct gpio_desc;
+struct of_phandle_args;
+struct device_node;
struct seq_file;
/**
@@ -125,6 +128,13 @@ extern struct gpio_chip *gpiochip_find(void *data,
int gpiod_lock_as_irq(struct gpio_desc *desc);
void gpiod_unlock_as_irq(struct gpio_desc *desc);
+enum gpio_lookup_flags {
+ GPIO_ACTIVE_HIGH = (0 << 0),
+ GPIO_ACTIVE_LOW = (1 << 0),
+ GPIO_OPEN_DRAIN = (1 << 1),
+ GPIO_OPEN_SOURCE = (1 << 2),
+};
+
/**
* Lookup table for associating GPIOs to specific devices and functions using
* platform data.
@@ -152,9 +162,9 @@ struct gpiod_lookup {
*/
unsigned int idx;
/*
* mask of GPIOF_* values
*/
- unsigned long flags;
+ enum gpio_lookup_flags flags;
};
/*
@@ -152,9 +162,9 @@ struct gpiod_lookup {
unsigned int idx;
/*
- * mask of GPIOF_* values
+ * mask of GPIO_* values
*/